# Welcome to pytest-tspwplib

A simple plugin to use with tspwplib


## License

Distributed under the terms of the MIT license, `pytest-tspwplib` is free and open source software

## Contributions

Contributions are very welcome. Tests can be run with `tox`_, please ensure
the coverage at least stays the same before you submit a pull request.

## Issues

If you encounter any problems, please file an issue along with a detailed description.
